Struct aws_sdk_codeguruprofiler::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for CodeGuruProfiler.
This client allows ergonomic access to a CodeGuruProfiler-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AddNotificationChannels operation.
See AddNotificationChannels for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchGetFrameMetricData operation.
See BatchGetFrameMetricData for more information about the
operation and its arguments.
Constructs a fluent builder for the ConfigureAgent operation.
See ConfigureAgent for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateProfilingGroup operation.
See CreateProfilingGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteProfilingGroup operation.
See DeleteProfilingGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeProfilingGroup operation.
See DescribeProfilingGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFindingsReportAccountSummary operation.
See GetFindingsReportAccountSummary for more information about the
operation and its arguments.
Constructs a fluent builder for the GetNotificationConfiguration operation.
See GetNotificationConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the GetPolicy operation.
See GetPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the GetProfile operation.
See GetProfile for more information about the
operation and its arguments.
Constructs a fluent builder for the GetRecommendations operation.
See GetRecommendations for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFindingsReports operation.
See ListFindingsReports for more information about the
operation and its arguments.
Constructs a fluent builder for the ListProfileTimes operation.
See ListProfileTimes for more information about the
operation and its arguments.
Constructs a fluent builder for the ListProfilingGroups operation.
See ListProfilingGroups for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the PostAgentProfile operation.
See PostAgentProfile for more information about the
operation and its arguments.
Constructs a fluent builder for the PutPermission operation.
See PutPermission for more information about the
operation and its arguments.
Constructs a fluent builder for the RemoveNotificationChannel operation.
See RemoveNotificationChannel for more information about the
operation and its arguments.
Constructs a fluent builder for the RemovePermission operation.
See RemovePermission for more information about the
operation and its arguments.
Constructs a fluent builder for the SubmitFeedback operation.
See SubmitFeedback for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateProfilingGroup operation.
See UpdateProfilingGroup for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.