Struct aws_sdk_codeguruprofiler::input::list_profiling_groups_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListProfilingGroupsInput
Implementations
The nextToken value returned from a previous paginated
ListProfilingGroups request where maxResults was used and the results
exceeded the value of that parameter. Pagination continues from the end of the previous results
that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
The nextToken value returned from a previous paginated
ListProfilingGroups request where maxResults was used and the results
exceeded the value of that parameter. Pagination continues from the end of the previous results
that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
The maximum number of profiling groups results returned by ListProfilingGroups
in paginated output. When this parameter is used, ListProfilingGroups only returns
maxResults results in a single page along with a nextToken response
element. The remaining results of the initial request
can be seen by sending another ListProfilingGroups request with the returned
nextToken value.
The maximum number of profiling groups results returned by ListProfilingGroups
in paginated output. When this parameter is used, ListProfilingGroups only returns
maxResults results in a single page along with a nextToken response
element. The remaining results of the initial request
can be seen by sending another ListProfilingGroups request with the returned
nextToken value.
A Boolean value indicating whether to include a description. If true,
then a list of
ProfilingGroupDescription
objects
that contain detailed information about profiling groups is returned. If false, then
a list of profiling group names is returned.
A Boolean value indicating whether to include a description. If true,
then a list of
ProfilingGroupDescription
objects
that contain detailed information about profiling groups is returned. If false, then
a list of profiling group names is returned.
Consumes the builder and constructs a ListProfilingGroupsInput