Struct aws_sdk_codeguruprofiler::input::GetFindingsReportAccountSummaryInput [−][src]
#[non_exhaustive]pub struct GetFindingsReportAccountSummaryInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub daily_reports_only: Option<bool>,
}Expand description
The structure representing the GetFindingsReportAccountSummaryRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The nextToken value returned from a previous paginated GetFindingsReportAccountSummary
request where maxResults was used and the results exceeded the value of that parameter.
Pagination continues from the end of the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
max_results: Option<i32>The maximum number of results returned by GetFindingsReportAccountSummary in paginated output.
When this parameter is used, GetFindingsReportAccountSummary only returns maxResults
results in a single page along with a nextToken response element. The remaining results of the initial
request can be seen by sending another GetFindingsReportAccountSummary request with the returned
nextToken value.
daily_reports_only: Option<bool>A Boolean value indicating whether to only return reports from daily profiles. If set
to True, only analysis data from daily profiles is returned. If set to False,
analysis data is returned from smaller time windows (for example, one hour).
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFindingsReportAccountSummary, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFindingsReportAccountSummary, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetFindingsReportAccountSummary>
Creates a new builder-style object to manufacture GetFindingsReportAccountSummaryInput
The nextToken value returned from a previous paginated GetFindingsReportAccountSummary
request where maxResults was used and the results exceeded the value of that parameter.
Pagination continues from the end of the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
The maximum number of results returned by GetFindingsReportAccountSummary in paginated output.
When this parameter is used, GetFindingsReportAccountSummary only returns maxResults
results in a single page along with a nextToken response element. The remaining results of the initial
request can be seen by sending another GetFindingsReportAccountSummary request with the returned
nextToken value.
A Boolean value indicating whether to only return reports from daily profiles. If set
to True, only analysis data from daily profiles is returned. If set to False,
analysis data is returned from smaller time windows (for example, one hour).