Struct aws_sdk_codeguruprofiler::input::ListProfileTimesInput [−][src]
#[non_exhaustive]pub struct ListProfileTimesInput {
pub profiling_group_name: Option<String>,
pub start_time: Option<Instant>,
pub end_time: Option<Instant>,
pub period: Option<AggregationPeriod>,
pub order_by: Option<OrderBy>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Expand description
The structure representing the listProfileTimesRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.profiling_group_name: Option<String>The name of the profiling group.
start_time: Option<Instant>The start time of the time range from which to list the profiles.
end_time: Option<Instant>The end time of the time range from which to list the profiles.
period: Option<AggregationPeriod>The aggregation period. This specifies the period during which an aggregation profile collects posted agent profiles for a profiling group. There are 3 valid values.
-
P1D— 1 day -
PT1H— 1 hour -
PT5M— 5 minutes
order_by: Option<OrderBy>The order (ascending or descending by start time of the profile) to
use when listing profiles. Defaults to TIMESTAMP_DESCENDING.
max_results: Option<i32>The maximum number of profile time results returned by ListProfileTimes
in paginated output. When this parameter is used, ListProfileTimes only returns
maxResults results in a single page with a nextToken response
element. The remaining results of the initial request
can be seen by sending another ListProfileTimes request with the returned
nextToken value.
next_token: Option<String>The nextToken value returned from a previous paginated
ListProfileTimes request where maxResults was used and the results
exceeded the value of that parameter. Pagination continues from the end of the previous results
that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListProfileTimes, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListProfileTimes, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListProfileTimes>
Creates a new builder-style object to manufacture ListProfileTimesInput
The name of the profiling group.
The start time of the time range from which to list the profiles.
The end time of the time range from which to list the profiles.
The aggregation period. This specifies the period during which an aggregation profile collects posted agent profiles for a profiling group. There are 3 valid values.
-
P1D— 1 day -
PT1H— 1 hour -
PT5M— 5 minutes
The order (ascending or descending by start time of the profile) to
use when listing profiles. Defaults to TIMESTAMP_DESCENDING.
The maximum number of profile time results returned by ListProfileTimes
in paginated output. When this parameter is used, ListProfileTimes only returns
maxResults results in a single page with a nextToken response
element. The remaining results of the initial request
can be seen by sending another ListProfileTimes request with the returned
nextToken value.
The nextToken value returned from a previous paginated
ListProfileTimes request where maxResults was used and the results
exceeded the value of that parameter. Pagination continues from the end of the previous results
that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.