Enum aws_sdk_codeguruprofiler::model::AgentParameterField [−][src]
#[non_exhaustive]
pub enum AgentParameterField {
MaxStackDepth,
MemoryUsageLimitPercent,
MinimumTimeForReportingInMilliseconds,
ReportingIntervalInMilliseconds,
SamplingIntervalInMilliseconds,
Unknown(String),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Maximum stack depth to be captured by the CodeGuru Profiler.
Percentage of memory to be used by CodeGuru profiler. Minimum of 30MB is required for the agent.
Minimum time in milliseconds between sending reports.
Reporting interval in milliseconds used to report profiles.
Sampling interval in milliseconds used to sample profiles.
Unknown(String)Unknown contains new variants that have been added since this code was generated.
Tuple Fields of Unknown
0: StringImplementations