Struct aws_sdk_codeguruprofiler::model::UserFeedback [−][src]
#[non_exhaustive]pub struct UserFeedback {
pub type: Option<FeedbackType>,
}Expand description
Feedback that can be submitted for each instance of an anomaly by the user. Feedback is be used for improvements in generating recommendations for the application.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<FeedbackType>Optional Positive or Negative feedback submitted by
the user about whether the recommendation is useful or not.
Implementations
Optional Positive or Negative feedback submitted by
the user about whether the recommendation is useful or not.
Creates a new builder-style object to manufacture UserFeedback