pub struct ListProfilingGroupsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListProfilingGroups.
Returns a list of profiling groups. The profiling groups are returned as ProfilingGroupDescription objects.
Implementations
Sourceimpl ListProfilingGroupsFluentBuilder
impl ListProfilingGroupsFluentBuilder
Sourcepub fn as_input(&self) -> &ListProfilingGroupsInputBuilder
pub fn as_input(&self) -> &ListProfilingGroupsInputBuilder
Access the ListProfilingGroups as a reference.
Sourcepub async fn send(
self,
) -> Result<ListProfilingGroupsOutput, SdkError<ListProfilingGroupsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListProfilingGroupsOutput, SdkError<ListProfilingGroupsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListProfilingGroupsOutput, ListProfilingGroupsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListProfilingGroupsOutput, ListProfilingGroupsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListProfilingGroupsPaginator
pub fn into_paginator(self) -> ListProfilingGroupsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The nextToken value returned from a previous paginated ListProfilingGroups request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The nextToken value returned from a previous paginated ListProfilingGroups request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The nextToken value returned from a previous paginated ListProfilingGroups request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of profiling groups results returned by ListProfilingGroups in paginated output. When this parameter is used, ListProfilingGroups only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListProfilingGroups request with the returned nextToken value.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of profiling groups results returned by ListProfilingGroups in paginated output. When this parameter is used, ListProfilingGroups only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListProfilingGroups request with the returned nextToken value.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of profiling groups results returned by ListProfilingGroups in paginated output. When this parameter is used, ListProfilingGroups only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListProfilingGroups request with the returned nextToken value.
Sourcepub fn include_description(self, input: bool) -> Self
pub fn include_description(self, input: bool) -> Self
A Boolean value indicating whether to include a description. If true, then a list of ProfilingGroupDescription objects that contain detailed information about profiling groups is returned. If false, then a list of profiling group names is returned.
Sourcepub fn set_include_description(self, input: Option<bool>) -> Self
pub fn set_include_description(self, input: Option<bool>) -> Self
A Boolean value indicating whether to include a description. If true, then a list of ProfilingGroupDescription objects that contain detailed information about profiling groups is returned. If false, then a list of profiling group names is returned.
Sourcepub fn get_include_description(&self) -> &Option<bool>
pub fn get_include_description(&self) -> &Option<bool>
A Boolean value indicating whether to include a description. If true, then a list of ProfilingGroupDescription objects that contain detailed information about profiling groups is returned. If false, then a list of profiling group names is returned.