Struct aws_sdk_codeguruprofiler::output::GetFindingsReportAccountSummaryOutput [−][src]
#[non_exhaustive]pub struct GetFindingsReportAccountSummaryOutput {
pub report_summaries: Option<Vec<FindingsReportSummary>>,
pub next_token: Option<String>,
}Expand description
The structure representing the GetFindingsReportAccountSummaryResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.report_summaries: Option<Vec<FindingsReportSummary>>The return list of
FindingsReportSummary
objects taht contain summaries of analysis results for all profiling groups in your AWS account.
next_token: Option<String>The nextToken value to include in a future GetFindingsReportAccountSummary request.
When the results of a GetFindingsReportAccountSummary request exceed maxResults, this
value can be used to retrieve the next page of results. This value is null when there are no more
results to return.
Implementations
The return list of
FindingsReportSummary
objects taht contain summaries of analysis results for all profiling groups in your AWS account.
The nextToken value to include in a future GetFindingsReportAccountSummary request.
When the results of a GetFindingsReportAccountSummary request exceed maxResults, this
value can be used to retrieve the next page of results. This value is null when there are no more
results to return.
Creates a new builder-style object to manufacture GetFindingsReportAccountSummaryOutput