Struct aws_sdk_codeguruprofiler::output::ListProfileTimesOutput [−][src]
#[non_exhaustive]pub struct ListProfileTimesOutput {
pub profile_times: Option<Vec<ProfileTime>>,
pub next_token: Option<String>,
}Expand description
The structure representing the listProfileTimesResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.profile_times: Option<Vec<ProfileTime>>The list of start times of the available profiles for the aggregation period in the specified time range.
next_token: Option<String>The nextToken value to include in a future ListProfileTimes request.
When the results of a ListProfileTimes request exceed maxResults, this
value can be used to retrieve the next page of results. This value is null when there are no more
results to return.
Implementations
The list of start times of the available profiles for the aggregation period in the specified time range.
The nextToken value to include in a future ListProfileTimes request.
When the results of a ListProfileTimes request exceed maxResults, this
value can be used to retrieve the next page of results. This value is null when there are no more
results to return.
Creates a new builder-style object to manufacture ListProfileTimesOutput